@@ -72,7 +72,7 @@ public:
 	double ArrowHeadB;
 	double ArrowHeadC;
 	double ArrowDist;
-	double ArrowPadding;
+	double ObjectPadding;
 	double SignPadding;
 	std::map<Object*, GnomeCanvasGroup*>Items;
 	std::list<Object*>SelectedObjects;
